@@ -58,6 +58,8 @@ void dMagnetic_loaderfailed_message(char* argv0)
 	fprintf(stderr,"%s -tworsc DIRECTORY/TWO.RSC\n",argv0);
 	fprintf(stderr,"%s -d64 IMAGE1.d64,IMAGE2.d64\n",argv0);
 	fprintf(stderr,"%s -amstradcpc IMAGE1.DSK,IMAGE2.DSK\n",argv0);
+	fprintf(stderr,"%s -spectrum IMAGE.DSK\n",argv0);
+	fprintf(stderr,"%s -archimedes IMAGE.adf\n",argv0);
 	fprintf(stderr,"\n");
 	fprintf(stderr,"You can get the .mag and .gfx files from\n");
 	fprintf(stderr," https://msmemorial.if-legends.org/\n");
@@ -248,6 +250,8 @@ int main(int argc,char** argv)
 		printf("                         or The Magnetic Scrolls Collection Vol.1\n");
 		printf("-d64 m1.d64,m2.d64       or use the D64 images. (Separated by ,)\n");
 		printf("-amstradcpc 1.DSK,2.DSK  or use the DSK images. (Separated by ,)\n");
+		printf("-spectrum image.DSK      or use DSK images from the Spectrum+3\n");
+		printf("-archimedes image.adf    or use adf/adl images from the Archimedes\n");
 		printf("\n");
 		printf("OPTIONAL PARAMETERS\n");
 		printf("-rmode RANDOMMODE  where mode is one of\n  [");
@@ -296,34 +300,46 @@ int main(int argc,char** argv)
 		printf(";pawnmsdos=/usr/local/share/games/magneticscrolls/msdosversions/PAWN\n");
 		printf(";pawnd64=/d64/PAWN1.d64,/d64/PAWN2.d64\n");
 		printf(";pawnamstradcpc=/dsk/PAWN1.DSK,/dsk/PAWN2.DSK\n");
+		printf(";pawnspectrum=/dsk/PAWNspectrum.DSK\n");
+		printf(";pawnarchimedes=/adf/PAWNarchimedes.adf\n");
 		printf("guildmag=/usr/local/share/games/magneticscrolls/guild.mag\n");
 		printf("guildgfx=/usr/local/share/games/magneticscrolls/guild.gfx\n");
 		printf(";guildmsdos=/usr/local/share/games/magneticscrolls/msdosversions/GUILD\n");
 		printf(";guildtworsc=/usr/local/share/games/magneticscrolls/MSC/GTWO.RSC\n");
 		printf(";guild64=/d64/GUILD1.d64,/d64/GUILD2.d64\n");
 		printf(";guildamstradcpc=/dsk/GUILD1.DSK,/dsk/GUILD2.DSK\n");
+		printf(";guildspectrum=/dsk/GUILDspectrum.DSK\n");
+		printf(";guildarchimedes=/adf/GUILDarchimedes.adf\n");
 		printf("jinxtermag=/usr/local/share/games/magneticscrolls/jinxter.mag\n");
 		printf("jinxtergfx=/usr/local/share/games/magneticscrolls/jinxter.gfx\n");
 		printf(";jinxtermsdos=/usr/local/share/games/magneticscrolls/msdosversions/JINXTER\n");
 		printf(";jinxterd64=/d64/JINXTER1.d64,/d64/JINXTER2.d64\n");
 		printf(";jinxteramstradcpc=/dsk/JINXTER1.DSK,/dsk/JINXTER2.DSK\n");
+		printf(";jinxterspectrum=/dsk/JINXTERspectrum.DSK\n");
+		printf(";jinxterarchimedes=/adf/JINXTERarchimedes.adf\n");
 		printf("corruptionmag=/usr/local/share/games/magneticscrolls/ccorrupt.mag\n");
 		printf("corruptiongfx=/usr/local/share/games/magneticscrolls/ccorrupt.gfx\n");
 		printf(";corruptionmsdos=/usr/local/share/games/magneticscrolls/msdosversions/CORRUPT\n");
 		printf(";corruptiontworsc=/usr/local/share/games/magneticscrolls/MSC/CTWO.RSC\n");
 		printf(";corruptiond64=/d64/CORRUPT1.d64,/d64/CORRUPT2.d64\n");
 		printf(";corruptionamstradcpc=/dsk/CORRUPTION1.DSK,/dsk/CORRUPTION2.DSK\n");
+		printf(";corruptionspectrum=/dsk/CORRUPTIONspectrum.DSK\n");
+		printf(";corruptionarchimedes=/adf/CORRUPTIONarchimedes.adf\n");
 		printf("fishmag=/usr/local/share/games/magneticscrolls/fish.mag\n");
 		printf("fishgfx=/usr/local/share/games/magneticscrolls/fish.gfx\n");
 		printf(";fishmsdos=/usr/local/share/games/magneticscrolls/msdosversions/FISH\n");
 		printf(";fishtworsc=/usr/local/share/games/magneticscrolls/MSC/FTWO.RSC\n");
 		printf(";fishd64=/d64/FISH1.d64,/d64/FISH2.d64\n");
 		printf(";fishamstradcpc=/dsk/FISH1.DSK,/dsk/FISH2.DSK\n");
+		printf(";fishspectrum=/dsk/FISHspectrum.DSK\n");
+		printf(";fisharchimedes=/adf/FISHarchimedes.adf\n");
 		printf("mythmag=/usr/local/share/games/magneticscrolls/myth.mag\n");
 		printf("mythgfx=/usr/local/share/games/magneticscrolls/myth.gfx\n");
 		printf(";mythmsdos=/usr/local/share/games/magneticscrolls/msdosversions/MYTH\n");
 		printf(";mythd64=/usr/local/share/games/magneticscrolls/MYTH.d64\n");
 		printf(";mythamstradcpc=/dsk/MYTH1.DSK,/dsk/MYTH2.DSK\n");
+		printf(";mythspectrum=/dsk/MYTHspectrum.DSK\n");
+		printf(";mytharchimedes=/adf/MYTHarchimedes.adf\n");
 		printf("wonderlandmag=/usr/local/share/games/magneticscrolls/wonder.mag\n");
 		printf("wonderlandgfx=/usr/local/share/games/magneticscrolls/wonder.gfx\n");
 		printf(";wonderlandtworsc=/usr/local/share/games/magneticscrolls/WONDER/TWO.RSC\n");
